'use strict';

const KubeClient = require('kubernetes-client');

const ServiceEvents         = require('./kube-native/service/svc.events');
const Service               = require('./kube-native/service/svc');
const ServiceBuilder        = require('./kube-native/service/svc.builder');
const ServiceStautsAnalyzer = require('./kube-native/service/svc.status.analyzer');
const ServiceController     = require('./kube-native/service/svc.controller');

const DeployEvents         = require('./kube-native/deployment/deploy.events');
const Deploy               = require('./kube-native/deployment/deploy');
const DeployBuilder        = require('./kube-native/deployment/deploy.builder');
const DeployStautsAnalyzer = require('./kube-native/deployment/deploy.status.analyzer');
const DeployController     = require('./kube-native/deployment/deploy.controller');


const NsEvents  = require('./kube-native/namespace/namespace.events');
const Ns        = require('./kube-native/namespace/namespace');
const NsBuilder = require('./kube-native/namespace/namespace.builder');

const CmEvents  = require('./kube-native/configMap/configMap.events');
const Cm        = require('./kube-native/configMap/configMap');
const CmBuilder = require('./kube-native/configMap/configMap.builder');

const SecretEvents           = require('./kube-native/secret/secret.events');
const Secret                 = require('./kube-native/secret/secret');
const SecretController       = require('./kube-native/secret/secret.controller');
// const SecretBuilder          = require('./kube-native/secret/secret.builder'); // builder not ready yet
const imagePullSecretBuilder = require('./kube-native/secret/image.pull.secret.builder');

const Rs               = require('./kube-native/replicaSet/rs');
const RsStautsAnalyzer = require('./kube-native/replicaSet/rs.status.analyzer');


const Pod         = require('./kube-native/pod/pod');
const PodAnalyzer = require('./kube-native/pod/pod.status.analyzer');
const PodController = require('./kube-native/pod/pod.controller');

const Node         = require('./kube-native/node/node');

const Helm3ReleaseController = require('./helm/release/helm3/release.controller');
const ReleaseController = require('./helm/release/helm2/release.controller');

const supportedResources = require('./kube-native/supported.recourses');




const initTypes = {
    CORE: KubeClient.Core,
    EXTENSION: KubeClient.Extensions
};

module.exports = function () {
    return [
        {
            name: supportedResources.service.name,
            Type: initTypes.CORE,
            events: ServiceEvents,
            baseKubePath: 'namespaces.services',
            Controller: ServiceController,
            Entity: Service,
            builders: [
                {
                    name: 'serviceBuilder',
                    Type: ServiceBuilder,
                    isDefault: true
                }
            ],
            StatusAnalyzer: ServiceStautsAnalyzer
        },
        {
            name: supportedResources.deployment.name,
            Type: initTypes.EXTENSION,
            events: DeployEvents,
            baseKubePath: 'namespaces.deployment',
            Controller: DeployController,
            Entity: Deploy,
            builders: [
                {
                    name: 'deploymentBuilder',
                    Type: DeployBuilder,
                    isDefault: true
                }
            ],
            StatusAnalyzer: DeployStautsAnalyzer
        },
        {
            name: supportedResources.namespace.name,
            Type: initTypes.CORE,
            events: NsEvents,
            baseKubePath: 'namespaces',
            Entity: Ns,
            builders: [
                {
                    name: 'namespaceBuilder',
                    Type: NsBuilder,
                    isDefault: true
                }
            ]
        },
        {
            name: supportedResources.node.name,
            Type: initTypes.CORE,
            baseKubePath: 'nodes',
            Entity: Node
        },
        {
            name: supportedResources.configmap.name,
            Type: initTypes.CORE,
            events: CmEvents,
            baseKubePath: 'namespaces.cm',
            Entity: Cm,
            builders: [
                {
                    name: 'configmapBuilder',
                    Type: CmBuilder,
                    isDefault: true
                }
            ]
        },
        {
            name: supportedResources.secret.name,
            Controller: SecretController,
            Type: initTypes.CORE,
            events: SecretEvents,
            baseKubePath: 'namespaces.secret',
            Entity: Secret,
            builders: [
                {
                    name: 'imagePullSecretBuilder',
                    Type: imagePullSecretBuilder
                }
            ]
        },
        {
            name: supportedResources.replicaset.name,
            Type: initTypes.EXTENSION,
            baseKubePath: 'namespaces.rs',
            Entity: Rs,
            StatusAnalyzer: RsStautsAnalyzer

        },
        {
            name: supportedResources.pod.name,
            Type: initTypes.CORE,
            baseKubePath: 'namespaces.pod',
            Entity: Pod,
            StatusAnalyzer: PodAnalyzer,
            Controller: PodController
        },
        {
            name: supportedResources.release.name,
            Type: initTypes.CORE,
            Controller: ReleaseController
        },
        {
            name: supportedResources.releaseHelm3.name,
            Type: initTypes.CORE,
            Controller: Helm3ReleaseController
        }
    ]
};
